import sys
import unittest
import pgmagick
from pgmagick import Blob, Image, Geometry, Color, LineJoin, StorageType
from pgmagick import ChannelType
from pgmagick import gminfo
if gminfo.library == 'ImageMagick':
    from pgmagick import DistortImageMethod, SparseColorMethod


class TestImage(unittest.TestCase):

    def test_noarg_init(self):
        im = Image()
        self.assertEqual(type(im), Image)

    def test_fromfile_init_error(self):
        self.assertRaises(RuntimeError, Image, "xXxX.jpg")

    def test_size_and_color_init(self):
        im = Image(Geometry(300, 200), Color('transparent'))
        size = im.size()
        self.assertEqual(300, size.width())
        self.assertEqual(200, size.height())

    def test_stroke_linejoin(self):
        im = Image(Geometry(300, 200), Color('transparent'))
        im.strokeLineJoin(LineJoin.MiterJoin)
        im.strokeLineJoin(LineJoin.RoundJoin)
        im.strokeLineJoin(LineJoin.BevelJoin)

    #def test_image_getpixels(self):
    #    img = Image(Geometry(300, 200), Color('transparent'))
    #    img.getPixels(10, 10, 10, 10)

    def test_image_init_storagetype(self):
        data = ["0" for i in range(10000)]
        img = Image(100, 100, "RGB", StorageType.CharPixel, "".join(data))

    #def test_haldClut(self):
    #    img = Image()
    #    if hasattr(img, "haldClut"):
    #        clutimg = Image(Geometry(400, 300), Color("transparent"))
    #        clutimg.read("gradient:white-black")
    #        img.haldClut(clutimg)


class TestIMImage(unittest.TestCase):

    def setUp(self):
        self.img = Image()
        self.is_imagemagick = False
        if gminfo.library == 'ImageMagick':
            self.is_imagemagick = True

    def test_adaptiveBlur(self):
        if self.is_imagemagick:
            self.img.adaptiveBlur()

    def test_distort(self):
        if self.is_imagemagick:
            self.img.distort(DistortImageMethod.ScaleRotateTranslateDistortion,
                             1, 1.0, True)

    def test_extent(self):
        if self.is_imagemagick:
            self.img.extent(Geometry(100, 100))

    def test_inverseFourierTransform(self):
        if self.is_imagemagick:
            phase = Image()
            self.img.inverseFourierTransform(phase)

    def test_sigmoidalContrast(self):
        if self.is_imagemagick:
            self.img.sigmoidalContrast(2, 2.)

    def test_splice(self):
        if self.is_imagemagick:
            self.img.splice(Geometry(100, 100))

    def test_sparseColor(self):
        if self.is_imagemagick:
            self.img.sparseColor(ChannelType.RedChannel,
                                 SparseColorMethod.PolynomialColorInterpolate,
                                 1, 1.)

    def test_sparseColor(self):
        if self.is_imagemagick:
            ret = self.img.exifProfile()
            self.assertEqual(type(ret), type(pgmagick._pgmagick.Blob()))

    def test_virtualPixelMethod(self):
        if self.is_imagemagick:
            ret = self.img.virtualPixelMethod()
            self.assertEqual(type(ret),
                             type(pgmagick._pgmagick.VirtualPixelMethod()))

unittest.main()



# coding: utf-8
import os.path
import unittest
from pgmagick import api
from pgmagick import Image, Geometry, Blob


class TestCookbook(unittest.TestCase):

    def setUp(self):
        self.tmp_filename_jpg = "_cookbook_test.jpg"
        self.tmp_filename_png = "_cookbook_test.png"

    def tearDown(self):
        if os.path.exists(self.tmp_filename_jpg):
            os.remove(self.tmp_filename_jpg)
        if os.path.exists(self.tmp_filename_png):
            os.remove(self.tmp_filename_png)

    def test_red_background_jpeg_image(self):
        img = api.Image((300, 200), 'red')
        img.write(self.tmp_filename_jpg)

    def test_transparent_png_image(self):
        img = api.Image((300, 200), 'transparent')
        img.write(self.tmp_filename_png)

    def test_gradient_png_image(self):
        img = api.Image((300, 200), 'gradient:#ffffff-#000000')
        img.write(self.tmp_filename_png)

    def test_annotate(self):
        img = api.Image((300, 200))
        img.annotate('Hello World')
        img.write(self.tmp_filename_png)

    def test_annotate_with_angle45(self):
        img = api.Image((300, 200))
        img.annotate('Hello World', angle=45)
        img.write(self.tmp_filename_png)

    def test_annotate_with_japanese_font(self):
        img = api.Image((300, 200))
        img.font("/usr/share/fonts/truetype/ttf-japanese-gothic.ttf")
        img.annotate('ようこそpgmagickへ!!')
        img.write(self.tmp_filename_png)

    def test_scale(self):
        img = api.Image((300, 200), 'blue')
        img.write(self.tmp_filename_png)
        img2 = api.Image(self.tmp_filename_png)
        img2.scale(0.5)
        img2.write(self.tmp_filename_png)
        self.assertEqual(img2.width, 150)
        self.assertEqual(img2.height, 100)

    def test_scale_with_lanczos(self):
        img = api.Image((300, 200), 'blue')
        img.write(self.tmp_filename_png)
        img2 = api.Image(self.tmp_filename_png)
        img2.scale((150, 100), 'lanczos')
        img2.write(self.tmp_filename_png)
        self.assertEqual(img2.width, 150)
        self.assertEqual(img2.height, 100)

    def test_scale_jpeg(self):
        img = api.Image((400, 400), 'blue')
        img.write(self.tmp_filename_jpg)
        img2 = Image(Blob(open(self.tmp_filename_jpg).read()),
                     Geometry(200, 200))
        img2.scale('200x200')
        img2.write(self.tmp_filename_jpg)

if __name__ == '__main__':
    unittest.main()
